/*
  Project: Arduino Uno, 3.5" TFT LCD shield
  Function: Display string example. The control pins for the LCD can be
  assigned to any digital or analog pins but we'll use the analog pins
  as this allows us to double up the pins with the touch screen.
  // Shield pin usage:
  // LCD Data Bit :    7    6    5    4    3    2    1    0
  // Digital pin #:    7    6   13    4   11   10    9    8
  // Uno port/pin :  PD7  PD6  PB5  PD4  PB3  PB2  PB1  PB0
  // Mega port/pin:  PH4  PH3  PB7  PG5  PB5  PB4  PH6  PH5
  // Leo port/pin :  PE6  PD7  PC7  PD4  PB7  PB6  PB5  PB4
  // Due port/pin : PC23 PC24 PB27 PC26  PD7 PC29 PC21 PC22

  // Breakout pin usage:
  // LCD Data Bit :   7   6   5   4   3   2   1   0
  // Uno dig. pin :   7   6   5   4   3   2   9   8
  // Uno port/pin : PD7 PD6 PD5 PD4 PD3 PD2 PB1 PB0
  // Mega dig. pin:  29  28  27  26  25  24  23  22
  // Mega port/pin: PA7 PA6 PA5 PA4 PA3 PA2 PA1 PA0 (one contiguous PORT)
  // Leo dig. pin :   7   6   5   4   3   2   9   8
  // Leo port/pin : PE6 PD7 PC6 PD4 PD0 PD1 PB5 PB4
  // Due dig. pin :  40  39  38  37  36  35  34  33
  // Due port/pin : PC8 PC7 PC6 PC5 PC4 PC3 PC2 PC1 (one contiguous PORT)

  IMPORTANT: Adafruit_TFTLCD library must be configured for the 3.5" TFT LCD shield
  or the breakout board. See comments about it in Adafruit_TFTLCD.h for proper setup.
*/
//*************************************************************************
#include <Adafruit_GFX.h>    // Core graphics library
#include <Adafruit_TFTLCD.h> // Hardware-specific library
//*************************************************************************
#define LCD_RESET A4 // Can alternately just connect to Arduino's reset pin
#define LCD_CS A3 // Chip Select goes to Analog 3
#define LCD_CD A2 // Command/Data goes to Analog 2
#define LCD_WR A1 // LCD Write goes to Analog 1
#define LCD_RD A0 // LCD Read goes to Analog 0

// Assign human-readable names to some common 16-bit color values:
#define	BLACK   0x0000
#define	BLUE    0x001F
#define	RED     0xF800
#define	GREEN   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define YELLOW  0xFFE0
#define WHITE   0xFFFF

Adafruit_TFTLCD tft(LCD_CS, LCD_CD, LCD_WR, LCD_RD, LCD_RESET);
// If using the shield, all control and data lines are fixed, and
// a simpler declaration can optionally be used:
// Adafruit_TFTLCD tft;

void setup(void) {
  Serial.begin(9600);
  Serial.println(F("Display string"));
#ifdef USE_ADAFRUIT_SHIELD_PINOUT
                 Serial.println(F("Using 3.5\" TFT Arduino Shield Pinout"));
#else
                 Serial.println(F("Using 3.5\" TFT Breakout Board Pinout"));
#endif

                 Serial.print("TFT size is "); Serial.print(tft.width()); Serial.print("x"); Serial.println(tft.height());

                 tft.reset();

                 uint16_t identifier = tft.readID();
                 identifier=0x9481;
  if (identifier == 0x9325) {
  Serial.println(F("Found ILI9325 LCD driver"));
  } else if (identifier == 0x9328) {
  Serial.println(F("Found ILI9328 LCD driver"));
  } else if (identifier == 0x7575) {
  Serial.println(F("Found HX8347G LCD driver"));
  } else if (identifier == 0x9341) {
  Serial.println(F("Found ILI9341 LCD driver"));
  } else if (identifier == 0x8357) {
  Serial.println(F("Found HX8357D LCD driver"));
  } else if (identifier == 0x9481) {
  Serial.println(F("Found ILI9481 LCD driver"));
  } else {
    Serial.print(F("Unknown LCD driver chip: "));
    Serial.println(identifier, HEX);
    Serial.println(F("If using the Adafruit 2.8\" TFT Arduino shield, the line:"));
    Serial.println(F("  #define USE_ADAFRUIT_SHIELD_PINOUT"));
    Serial.println(F("should appear in the library header (Adafruit_TFT.h)."));
    Serial.println(F("If using the breakout board, it should NOT be #defined!"));
    Serial.println(F("Also if using the breakout, double-check that all wiring"));
    Serial.println(F("matches the tutorial."));
    return;
  }

  tft.begin(identifier);


}

void loop(void) {
  tft.fillScreen(BLACK);
  unsigned long start = micros();
  tft.setCursor(0, 0);

  tft.setTextColor(RED);  tft.setTextSize(1);
  tft.println("Welcome to Acoptex!");
  tft.println(7777);
  tft.println();
  tft.println();
  tft.setTextColor(GREEN); tft.setTextSize(2);
  tft.println("Welcome to Acoptex!");
  tft.println(7777);
  tft.println();
  tft.println();

  tft.setTextColor(BLUE);    tft.setTextSize(3);
  tft.println("Welcome to Acoptex!");
  tft.println(7777);


  tft.setTextColor(WHITE);    tft.setTextSize(4);
  tft.println("WELCOME!");
  tft.setTextColor(YELLOW);    tft.setTextSize(5);
  tft.println("WELCOME!");
  tft.setTextColor(RED);    tft.setTextSize(6);
  tft.println("WELCOME!");
  tft.println();
  tft.println();
  /*
    tft.println();
    tft.setTextColor(GREEN);
    tft.setTextSize(5);
    tft.println("Find");
    tft.setTextSize(2);
    tft.println("more projects at ");
    tft.setTextSize(1);
    tft.println("acoptex.com");*/
  delay(1000); delay(1000); delay(1000); delay(1000); delay(1000);
}
